package envoy.client.ui.control;

import javafx.geometry.*;
import javafx.scene.control.Label;
import javafx.scene.image.Image;
import javafx.scene.layout.*;

import envoy.client.data.*;
import envoy.client.util.IconUtil;

/**
 * Displays a chat using a contact control for the recipient and a label for the
 * unread message count.
 *
 * @see ContactControl
 * @author Leon Hofmeister
 * @since Envoy Client v0.1-beta
 */
public final class ChatControl extends HBox {

	private static final Image userIcon = IconUtil.loadIconThemeSensitive("user_icon", 32),
			groupIcon = IconUtil.loadIconThemeSensitive("group_icon", 32);

	/**
	 * Creates a new {@code ChatControl}.
	 *
	 * @param chat the chat to display
	 * @since Envoy Client v0.1-beta
	 */
	public ChatControl(Chat chat) {
		setAlignment(Pos.CENTER_LEFT);
		setPadding(new Insets(0, 0, 3, 0));

		// Profile picture
		final var contactProfilePic = new ProfilePicImageView(chat instanceof GroupChat ? groupIcon : userIcon, 32);
		getChildren().add(contactProfilePic);

		// Spacing
		final var leftSpacing = new Region();
		leftSpacing.setPrefSize(8, 0);
		leftSpacing.setMinSize(8, 0);
		leftSpacing.setMaxSize(8, 0);
		getChildren().add(leftSpacing);

		// Contact control
		getChildren().add(new ContactControl(chat.getRecipient()));

		// Unread messages
		if (chat.getUnreadAmount() != 0) {
			final var spacing = new Region();
			setHgrow(spacing, Priority.ALWAYS);
			getChildren().add(spacing);
			final var unreadMessagesLabel = new Label(Integer.toString(chat.getUnreadAmount()));
			unreadMessagesLabel.setMinSize(15, 15);
			final var vbox = new VBox();
			vbox.setAlignment(Pos.CENTER_RIGHT);
			unreadMessagesLabel.setAlignment(Pos.CENTER);
			unreadMessagesLabel.getStyleClass().add("unread-messages-amount");
			vbox.getChildren().add(unreadMessagesLabel);
			getChildren().add(vbox);
		}
		getStyleClass().add("list-element");
	}
}
